'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.storyFilter = storyFilter;

var _fuzzysearch = require('fuzzysearch');

var _fuzzysearch2 = _interopRequireDefault(_fuzzysearch);

var _lodash = require('lodash.sortby');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function sort(stories, sortStoriesByKind) {
  if (!sortStoriesByKind) return stories;

  return (0, _lodash2.default)(stories, ['kind']);
}

function storyFilter(stories, filter, selectedKind, sortStoriesByKind) {
  if (!stories) return null;
  var sorted = sort(stories, sortStoriesByKind);
  if (!filter) return sorted;
  return sorted.reduce(function (acc, kindInfo) {
    // Don't filter out currently selected filter
    if (kindInfo.kind === selectedKind) return acc.concat(kindInfo);
    var needle = filter.toLocaleLowerCase();
    var hstack = kindInfo.kind.toLocaleLowerCase();

    // If a match is found in the story hierachy structure return kindInfo
    if ((0, _fuzzysearch2.default)(needle, hstack)) return acc.concat(kindInfo);

    // Now search at individual story level and filter results
    var matchedStories = kindInfo.stories.filter(function (story) {
      var storyHstack = story.toLocaleLowerCase();
      return (0, _fuzzysearch2.default)(needle, storyHstack);
    });

    if (matchedStories.length) return acc.concat({
      kind: kindInfo.kind,
      stories: matchedStories
    });

    return acc;
  }, []);
}